==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/features/sharding/distsql/statement/src/main/java/org/apache/shardingsphere/sharding/distsql/statement/CreateDefaultShardingStrategyStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.distsql.statement;

import lombok.Getter;
import org.apache.shardingsphere.distsql.segment.AlgorithmSegment;
import org.apache.shardingsphere.distsql.statement.rdl.rule.database.type.CreateRuleStatement;

/**
 * Create default sharding strategy statement.
 */
@Getter
public final class CreateDefaultShardingStrategyStatement extends CreateRuleStatement {
    
    private final String defaultType;
    
    private final String strategyType;
    
    private final String shardingColumn;
    
    private final AlgorithmSegment algorithmSegment;
    
    public CreateDefaultShardingStrategyStatement(final boolean ifNotExists, final String defaultType, final String strategyType,
                                                  final String shardingColumn, final AlgorithmSegment algorithmSegment) {
        super(ifNotExists);
        this.defaultType = defaultType;
        this.strategyType = strategyType;
        this.shardingColumn = shardingColumn;
        this.algorithmSegment = algorithmSegment;
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/features/sharding/distsql/statement/src/main/java/org/apache/shardingsphere/sharding/distsql/statement/CreateDefaultShardingStrategyStatement.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sharding.distsql.statement;

import lombok.Getter;
import org.apache.shardingsphere.distsql.segment.AlgorithmSegment;
import org.apache.shardingsphere.distsql.statement.type.rdl.rule.database.type.CreateRuleStatement;

/**
 * Create default sharding strategy statement.
 */
@Getter
public final class CreateDefaultShardingStrategyStatement extends CreateRuleStatement {
    
    private final String defaultType;
    
    private final String strategyType;
    
    private final String shardingColumn;
    
    private final AlgorithmSegment algorithmSegment;
    
    public CreateDefaultShardingStrategyStatement(final boolean ifNotExists, final String defaultType, final String strategyType,
                                                  final String shardingColumn, final AlgorithmSegment algorithmSegment) {
        super(ifNotExists);
        this.defaultType = defaultType;
        this.strategyType = strategyType;
        this.shardingColumn = shardingColumn;
        this.algorithmSegment = algorithmSegment;
    }
}
